@@ -4,6 +4,7 @@
 #'
 #' @param x object returned from \code{local_variable_importance()} function
 #' @param ... other parameters
+#' @param title the plot's title, by default \code{'Local variable importance'}
 #' @return a ggplot2 object
 #'
 #' @examples
@@ -35,14 +36,14 @@
 #' @export
 #'
 
-plot.local_importance <- function(x, ...){
+plot.local_importance <- function(x, ..., title = "Local variable importance"){
   df <- as.data.frame(x)
-  ggplot(df, aes(x = factor(df$variable_name , levels = df$variable_name[order(df$measure)]), y = df$measure)) +
-    geom_bar(stat = "identity", width = 0.5, fill = theme_drwhy_colors(1)) +
+  obs <- attr(x, "observation")
+  df$variable_measure <- paste0(df$variable_name, " = ", obs[1:nrow(df)])
+  ggplot(df, aes(x = factor(df$variable_measure , levels = df$variable_measure[order(df$measure)]), y = df$measure)) +
+    geom_bar(stat = "identity", width = 0.5, fill = colors_discrete_drwhy(1)) +
     coord_flip() +
-    xlab("") +
-    ylab("measure") +
-    ggtitle("") +
+    labs(x = "", y = "Measure", title = title, subtitle = paste0("For ", obs$`_label_`, ", ID: ", obs$`_ids_`)) +
     theme_drwhy_vertical() +
     theme(legend.position = "none")
 }
